# Bead Calibration

Calibrate arbitrary channels to molecules-of-fluorophore using fluorescent beads (eg, the Spherotech RCP-30-5A rainbow beads.)

Computes a log-linear calibration function that maps arbitrary fluorescence units to physical units (ie molecules equivalent fluorophore, or MEF).

To use, set Beads to the beads you calibrated with (check the lot!) and Beads File to an FCS file containing events collected using the same cytometer settings as the data you’re calibrating. Then, click Add a channel to add the channels to calibrate, and set both the channel name and the units you want calibrate to. Click Estimate, and make sure you check the diagnostic plot to see that the correct peaks were found.

If it didn’t find all the peaks (or found too many), try tweaking Peak Quantile, Peak Threshold and Peak Cutoff. If you can’t make the peak finding work by tweaking , please submit a bug report!

Beads

  The beads you’re calibrating with. Make sure to check the lot number!

Beads file

  A file containing the FCS events from the beads.

Channels

  A list of the channels you want calibrated and the units you want them calibrated in.

Peak Quantile

  Peaks must be at least this quantile high to be considered. Default = 80.

Peak Threshold

  Don’t search for peaks below this brightness. Default = 100.

Note

It works best to choose units of a fluorophore that is spectrally matched to the channel that you’re calibrating. Here are the beads that `Cytoflow` knows about (including the laser and filter sets used to characterize the beads):

- Spherotech ACP 30-2K

- Spherotech RCP-30-5A Lot AN04, AN03, AN02, AN01, AM02, AM01, AL01, AK04, AK03 & AK02**

- Spherotech RCP-30-5A (Euroflow) Lot EAM02 & EAM01

- Sphreotech RCP-30-5A (Euroflow) Lot EAK01, EAG01, EAE01 & EAF01

- Spherotech RCP-30-5A Lot AK01, AJ01, AH02, AH01, AF02, AF01, AD04 & AE01

- Spherotech RCP-30-5A Lot AG01

- Spherotech RCP-30-5A Lot AA01, AA02, AA03, AA04, AB01, AB02, AC01 & GAA01-R

- Spherotech RCP-30-5A Lot AC02, AC03 & AD01

- Spherotech RCP-30-5A Lot Z02 and Z03

- Spherotech RCP-30-5 Lot AA01, AB01, AB02, AC01 & AD01

- Spherotech RCP-30-5 Lot AM02, AM01, AL01, AH01, AG01, AF01 & AD03

- Spherotech RCP-60-5

- Spherotech URCP 38-2K

- Spherotech URCP 38-2K Lot AN01, AM01, AL02, AL01, AK03, AK02, AK01, AJ02 & AJ03

- Spherotech URCP 50-2K Lot AM01 & AJ01

- Spherotech URCP 50-2K

The Spherotech fluorophores labels and the laser / filter sets (that I know about) are:

- MECSB (Cascade Blue, 405 –> 450/50)

- MEBFP (BFP, 405 –> 530/40)

- MEFL (Fluroscein, 488 –> 530/40)

- MEPE (Phycoerythrin, 488 –> 575/25)

- MEPTR (PE-Texas Red, 488 –> 613/20)

- MECY (Cy5, 488 –> 680/30)

- MEPCY7 (PE-Cy7, 488 –> 750 LP)

- MEAP (APC, 633 –> 665/20)

- MEAPCY7 (APC-Cy7, 635 –> 750 LP)